@@ -22,7 +22,7 @@ has missing_after => 1800;
 has remove_after  => 172800;
 has tasks         => sub { {} };
 
-our $VERSION = '9.10';
+our $VERSION = '9.11';
 
 sub add_task { ($_[0]->tasks->{$_[1]} = $_[2]) and return $_[0] }
 
@@ -131,7 +131,7 @@ sub _backoff { (shift()**4) + 15 }
 sub _datetime {
   my $hash = shift;
   $hash->{$_} and $hash->{$_} = Mojo::Date->new($hash->{$_})->to_datetime
-    for qw(created delayed expires finished notified retried started);
+    for qw(created delayed expires finished notified retried started time);
   return $hash;
 }
 
