@@ -404,6 +404,12 @@ Current job state, usually C<active>, C<failed>, C<finished> or C<inactive>.
 
 Task name.
 
+=item time
+
+  time => 78411177
+
+Server time.
+
 =item worker
 
   worker => '154'
